/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view.failuretests;

import java.awt.Insets;
import java.io.File;

import junit.framework.TestCase;

import com.topcoder.rules.dependencymap.view.Dependency;
import com.topcoder.rules.dependencymap.view.FixedGridLayoutManager;
import com.topcoder.rules.dependencymap.view.RendererException;
import com.topcoder.rules.dependencymap.view.RendererGraphics;
import com.topcoder.rules.dependencymap.view.SVGRenderer;
import com.topcoder.rules.dependencymap.view.ShapeFactory;

/**
 * Failure test cases for FixedGridLayoutManager.
 *
 * @author AdamSelene
 */
public class FGLTest extends TestCase {
    
	private Insets goodInset = new Insets(1,2,3,4);
	private Dependency goodDep = new Dependency("test");
	private SVGRenderer svgr = new SVGRenderer(new File("."));
	private ShapeFactory goodSF = new ShapeFactory();
	
	/**
     * Valid input to layout.
     * 
	 * @throws RendererException to Junit.
     */
	public void testLayout_Silent() throws RendererException {
        new FixedGridLayoutManager().layout(goodDep, goodSF, svgr);
    }

	
	/**
     * Invalid input to layout.
     *
     * @throws RendererException to Junit.
     */
	public void testLayout_N1() throws RendererException {
        try {
            new FixedGridLayoutManager().layout(null, goodSF, svgr);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

	/**
     * Invalid input to layout.
     *
     * @throws RendererException to Junit.
     */
	public void testLayout_N2() throws RendererException {
        try {
            new FixedGridLayoutManager().layout(goodDep, null, svgr);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

	/**
     * Invalid input to layout.
     *
     * @throws RendererException to Junit.
     */
	public void testLayout_N3() throws RendererException {
        try {
            new FixedGridLayoutManager().layout(goodDep, goodSF, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

	/**
     * Invalid input to layout.
     *
     * @throws RendererException to Junit.
     */
	public void testLayout_N4() throws RendererException {
        try {
            new FixedGridLayoutManager().layout(null, null, svgr);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

	/**
     * Invalid input to layout.
     *
     * @throws RendererException to Junit.
     */
	public void testLayout_N5() throws RendererException {
        try {
            new FixedGridLayoutManager().layout(null, goodSF, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

	/**
     * Invalid input to layout.
     *
     * @throws RendererException to Junit.
     */
	public void testLayout_N6() throws RendererException {
        try {
            new FixedGridLayoutManager().layout(goodDep, null, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

	/**
     * Invalid input to layout.
     *
     * @throws RendererException to Junit.
     */
	public void testLayout_N7() throws RendererException {
        try {
            new FixedGridLayoutManager().layout(null, null, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }	
}
